%  --------------------------------------------------------------------------
%  Periodic solutions of the Duffing equation
%                       using the Harmonic Balance Method with the ANM
%  -------------------------------------------------------------------------
%
%  Duffing equation reads :
%   u'' + mu u' + omega0^2 u + Gamma u^3 =  FF cos(lambda t)  
%  where u(t) is the unkown function and lambda a real-valued parameter. 
%
%   let use  v = u'
%            w = u^2
%           
%   we rewrite the original equation as a quadratic, 1st order ODE system (Neq equations)
%
%    u'  =                    +   v
%    v'  =    FF cos(lambda t) - ome0^2 u  - mu v  - Gamma * uw 
%    0   =     0              +   w          - u^2
%   
%
%  We use the following formalism as input to the ANM
%
%   m(u') = c + l(u) + q(u,u)
%
%  with : l(u) linear operator, q(u,u) quadratic and u(t)= [ u , v , w  ]
%  
%  The Harmonic Balance Method   :
%  -------------------------------------
%
%  We seek periodic solutions (H harmonics) that can be written as :
%
%  u(t) = u0 + u1c cos(omega t) + u1s sin(omega t) + u2c cos(2 Omega t) + u2s sin(2 Omega t) + ... 
%              ...  + uHc cos(H omega t) + uHs sin(H omega t).
%
%  the HBM leads to a system of algebraic equations with a size of
%  Neq*(2*H+1) under the formalism :
%
%      C  + L(U)  - lambda  M(U) + Q(U,U)  = 0 
%
%  where U=[u0  u1c u1s  u2c u2s  ...  uHs, lambda]
%  
%
%  Writing C, L(U) and Q(U,U) as functions of c, l(u) and q(u,u)
%  is systematic and is described in the relevant publication [Cochelin &
%  Vergez, JSV 2008]. It has been automated, as it is already written in
%  the MATLAB functions L0.m, L.m and Q.m of the documented examples.
%
%--------------------------------------------------------------------------

 close all
 clear all
 clear classes

 % use this or define your path to MANLAB sources in your pathdef.m
addpath('~/MANLAB-2.0-beta/SRC')
 
 % initialise all MANLAB variables and parameters
 manlabinit;


%% Problem size and parameters
% number of harmonics for the HBM
H= 12;
% number of equation of the quadratic system (before HBM equations)
Neq=3;


%%% Parameters : make sure you modify their values in
%%%     the preamble of petits_operateurs.f90
%%% or in the matlab functions 'L0.m', 'L.m' and 'Q.m'
%  mu = 0.1;
%  omega0 = 1;
%  FF = 1.25;
%  Gamma = 1;
 

%% Fortran acceleration : compilation
% comment the following line to ignore Fortran acceleration
[status,result]=unix('cd @DUFF1HB && make && cd ..','-echo');
% uncomment the following to remove Fortran acceleration
% [status,result]=unix('cd @DUFF1HB && make clean && cd ..','-echo');

% creating oject of the class DUFF1HB
ML_problem = DUFF1HB(H,Neq); 

% % WARNING : the equation parameters must be modified in the preamble of
% % the file 'petits_operateurs.f90' if using Fortran acceleration
% % or in the matlab functions 'L0.m', 'L.m' and 'Q.m'
%%%%%%%%%%%%%%%%%%%%%%
 
%% Change a few ANM parameters
% number of points per portion to be evaluated for display
ML_problem = set_nbptstroncon(ML_problem,20);
% order of the power series in the ANM (default : 20)
ML_problem = set_ordre(ML_problem,15);
% number of time samples for monodromy matrix computation (used if
% ML_algostab=1 only)
ML_problem = set_nech(ML_problem,1000);

%% Starting point (approx.)
ML_Ustart  = zeros(Neq*(2*H+1)+1,1);
ML_Ustart(end)= 0.01;


%% Stability analysis : which variables are needed for the jacobian
% Here we need only U(1), so index is 1.
% ML_varstab = [ index1 index2 ... index_of_lambda index_of_omega H ]
ML_varstab = [1 Neq*(2*H+1)+1 Neq*(2*H+1)+1 H];
 
%% Variables we want to be displayed
% use the form : [abscissa1,ordinate1; abscissa2,ordinate2...]
ML_dispvars = [(2*H+1)*Neq+1  4 ; (2*H+1)*Neq+1  7 ];

%% Various parameters for MANLAB
% Do we want to compute the stability analysis ([1=yes], 0=no)
ML_stability = 1;
% If yes, which algo should be used (1=time integ., [2=Hill])
ML_algostab = 2;

% Do we want to display point-specific plots
ML_pointdisplay = 0;
% Do we want to display user defined global plots (like bif. diag., ...)
ML_globaldisplay = 0;



%% Start the programm
manlabstart; 
