% calcperiodHBM   Periodic solution computation
%    UU = calcperiodHBM(tt,H,Neq,U,Idisp) computes periodic 
%    solutions computed by the Manlab/HBM method.
%
%    tt is the dimensionless input time vector in seconds/T, where T is
%    the period in seconds.
%
%    U is the vector of unknowns of the final algebraic system solved
%    by Manlab. 
% 
%    Idisp contains the indices of the entries of the initial physical 
%    unknown vector u(t) to be computed.
%
%    H is the number of harmonics of the simulation.
%
%    Neq is the number of equations of the initial system of unknown
%    u(t)
%
%    It returns UU, a matrix of size (length(idisp),length(tt)), 
%    containing the values of the periodic solutions.
%
%    Example: UU=calcperiodHBM(tt,obj.H,obj.Neq,U,[1 2])
%
%    By O. Thomas / Oct. 2010

function  UU=calcperiodHBM(tt,H,Neq,U,Idisp)

Ndisp=length(Idisp);
UU=[];

for ii=1:length(Idisp)
  Icalc=Idisp(ii):Neq:(2*H+1)*Neq;
  Ucalc=U(Icalc);
  uu=calc_periodic(tt,Ucalc);
  UU=[UU;uu];
end

function  utt=calc_periodic(tt,U)
% Computes the periodic time series
%
% u(t)=U0 + U1c cos t + U1s sin t + ... + UHc cos H*t + UHs sin H*t
% U=[U0 U1c U1s U2c U2s ... UHc UHs]
%
% function utt=trac_periodic(tt,U);

L=length(U);
H=(L-1)/2;

if (H-floor(H))~=0
  disp('Mauvaise taille de vecteur U')
  Umax=NaN;Umin=NaN;Umoy=NaN;
  tmin=NaN;tmax=NaN;
  return
end

utt=ones(size(tt))*U(1);

for hh=1:H
  utt=utt+U(2*hh)*cos(2*pi*hh*tt)+U(2*hh+1)*sin(2*pi*hh*tt);
end

