% plotbranchbifHBM   Branch plot for Manlab/HBM.
%    Hand=plotbranchbifHBM(H,Neq,Nds,U,Ustab,Idisp,Hdisp,fig) plots the 
%    amplitude of the harmonics components of the solution computed by the
%    Manlab/HBM method as a function of the agular frequency
%    (omega=U(end,:)).
%    It also displays the bifurcation points:
%    - B for a simple bifurcation (saddle-node, pitchfork...)
%    - PD for period doubling bifurcation
%    - NS for Neimark-Sacker bifurcation
%
%    U is the vector of unknowns of the final algebraic system solved
%    by Manlab and Ustab the stability data. 
% 
%    Idisp contains the indices of the entries of the initial physical 
%    unknown vector u(t) to be displayed and Hdisp the corresponding
%    harmonics number.
%
%    H is the number of harmonics of the simulation.
%
%    Neq is the number of equations of the initial system of unknown
%    u(t)
%
%    Nds is the initial dynamical system size (this is also the number
%    of Floquet multipliers)
%
%    fig is a figure/axis handle to plot the bargraph on.
%
%    It returns in Hand a column vector of handles to lineseries objects, 
%    one handle per plotted line.
%
%    Example: Hand=plotbranchbifHBM(obj.H,obj.Neq,2,U,Ustab,[1 1 1],[1 3 5],1)
%             plots the three first odd harmonics (H=1, 3, 5) of u1. 
%
%    By O. Thomas / Sept. 2010

function Hand=plotbranchbifHBM(H,Neq,Nds,U,Ustab,Idisp,Hdisp,fig)

pencolorML;
style = {':','-'};

% Activate axis
% =============

if floor(fig)==fig
  figure(fig)
  hold on
else
  axes(fig)
  hold on
end

% Plotting the branches
% =====================

%  0 1 1 1 1 1  1 0 0 0 0 0 0
%0 1 1 1 1 1 1  0 0 0 0 0 0
%  1 0 0 0 0 0 -1 0 0 0 0 0

Nb=length(Idisp);
Hand=[];
Handleg=[];
hold on

omega = U(end,:);
%stab = Ustab(1,:);  
[Bbif,stab]=detectbifurcHBM(Nds,U,Ustab);
Ibif=[1 Bbif(1,:) size(U,2)];
Tbif=Bbif(2,:);

for ib=1:Nb
  idisp=Idisp(ib);
  hdisp=Hdisp(ib);
  colloc=Col(ib,:);
  if hdisp==0
    I0=idisp;
    Amp=U(I0,:);
  else
    Icos=Neq+idisp+(hdisp-1)*2*Neq;
    Amp=sqrt(U(Icos,:).^2+U(Icos+Neq,:).^2);
  end
  for bb=1:(length(Ibif)-1)
    II=Ibif(bb):Ibif(bb+1);
    st=style{stab(Ibif(bb)+1)+1};
    hand=plot(omega(II),Amp(II),st,'Color',colloc,'linewidth',1);
    Hand=[Hand;hand];
    if stab(Ibif(bb)+1)==1
      Handleg(ib)=hand;
    end
  end
  if length(Handleg)<ib
    Handleg(ib)=hand;
  end
  plot(omega(Ibif(2:end-1)),Amp(Ibif(2:end-1)),'.','Color',colloc)
  Leg{ib}=['H_',num2str(hdisp),'u_',num2str(idisp)];
  for ib=1:size(Bbif,2)
    ibif=Bbif(1,ib);
    tbif=Bbif(2,ib);
    switch tbif
     case 1
      str='B';
     case 2
      str='PD';
     case 3
      str='NS';
    end
    text(omega(ibif),Amp(ibif),str,'margin',3,'verticalalignment','Bottom')
  end
end
legend(Handleg,Leg,'location','best')
box on
ylabel('Harmonics amplitude')
xlabel('Angular frequency')
  
  
return

% Plotting the bargraph
% =====================


if floor(fig)==fig
  figure(fig)
  clf
  hold on
else
  axes(fig)
  hold on
end

Utrac=[];
Hand=[];
Ndisp=length(Idisp);

for iu=1:Ndisp
  idisp=Idisp(iu);
  colloc=Col(iu,:);
  Xtick=iu:Ndisp:(Ndisp*H+iu);
  Icos=Neq+(idisp:2*Neq:((H-1)*2*Neq+idisp));
  Isin=2*Neq+(idisp:2*Neq:((H-1)*2*Neq+idisp));
  Ubar=sqrt(U(Icos).^2+U(Isin).^2);
  Ubar=[U(idisp);Ubar];
  hand=bar(Xtick,Ubar);
  set(hand,'Facecolor',colloc,'barwidth',.8/Ndisp)
  Hand=[Hand;hand];
  Leg{iu}=['u_',num2str(idisp)];
end

% Labels
% ======

Xtick=1:Ndisp:(H+1)*Ndisp;
Ntick=length(Xtick);
Xtickstr=cell(1,Ntick);
Xtickstr{1}='H0';
for ii=2:Ntick
  Xtickstr{ii}=['H',num2str(ii-1)];
end

dI=ceil(H/10);
if dI>1
  Xtickstr0=cell(1,Ntick);
  Xtickstr0(2:dI:end)=Xtickstr(2:dI:end);
  Xtickstr=Xtickstr0;
end

set(gca,'Xtick',Xtick,'XtickLabel',Xtickstr,'Xlim',[0 (H+1)*Ndisp+1],'Xgrid','on')
ylabel('Harmonics amplitude')
box on

legend(Hand,Leg);


